@@ -53,11 +53,11 @@ kHeaders = {'Accept': 'application/json', 'Content-Type':'application/json'}
 kTaskActiveSuperstatusList = ['running', 'submitting', 'registered', 'ready']
 KTaskFinalSuperstatusList = ['finished', 'failed', 'done', 'broken', 'aborted']
 kStandardColumns = ['jeditaskid', 'status', 'pctfinished','taskname']
-kOutputColumns = ['jeditaskid', 'status', 'taskname', 'computingsite', 'metastruct']
+kOutputColumns = ['jeditaskid', 'status', 'taskname', 'computingsite', 'site', 'metastruct']
 
 kStatusLen = 8
 kLine = '_'*90
-kStrf = '{jeditaskid:>10}  {status:<{l}}  {pctfinished:>5} {computingsite:>10} {taskname}'
+kStrf = '{jeditaskid:>10}  {status:<{l}}  {pctfinished:>5} {taskname}'
 kHead = kStrf.format(l=kStatusLen, status='Status', jeditaskid='JediTaskID',
     pctfinished='Fin%', taskname='TaskName') +'\n' + kLine
 
@@ -132,16 +132,20 @@ class PandaTaskManager():
             parser.add_argument('-i', '--jeditaskid',
                 help='only show the task with the specified jeditaskid')
             parser.add_argument('-m', '--metadata', action='store_true',
-                help='check to print out the metadata of a task')
-            parser.add_argument('-s', '--sync', action='store_true', help=_h_test)
-            parser.add_argument('-r', '--range', help=_h_test)
-            parser.add_argument('-o', '--output', help='output file name')
-            parser.add_argument('-c', '--outcol', help='data columns to be saved in output',
+                help='print out the metadata of a task')
+            parser.add_argument('-s', '--sync', action='store_true',
+                help='force no caching on the PanDA server')
+            parser.add_argument('-r', '--range',
+                help='filter tasks by jeditaskid range')
+            parser.add_argument('-o', '--output',
+                help='output result with the filename if specified')
+            parser.add_argument('-c', '--outcol',
+                help='data columns to be saved in output',
                 default=kOutputColumns)
         elif (method in ['kill', 'retry', 'killAndRetry']):
-            parser = argparse.ArgumentParser(description='kill a PanDA task',
+            parser = argparse.ArgumentParser(description='kill/retry a PanDA task',
                         formatter_class=argparse.RawDescriptionHelpFormatter)   
-            parser.add_argument('jeditaskid', help=_h_test)   
+            parser.add_argument('jeditaskid', help='jeditaskid of the task')   
 
         return parser
 
