@@ -62,7 +62,7 @@ class SteeringIDDS():
         self.generate_points(**vars(args))
 
     def validate_idds_input(self, idds_input):
-        keys = ['points', 'opt_space']
+        keys = ['points']
         for key in keys:
             if key not in idds_input:
                 raise KeyError('Key {} not found in idds input.'
@@ -70,7 +70,7 @@ class SteeringIDDS():
         if not isinstance(idds_input['points'], List):
             raise ValueError('idds should have the data structure: Dict[List[...]]')
 
-        for point in points:
+        for point in idds_input['points']:
             if not isinstance(point, List):
                 raise ValueError('idds should have the data structure: Dict[List[List[...]]]')
             elif not isinstance(point[0], Dict):
