@@ -1,6 +1,7 @@
 import os
 import sys
 import json
+import multiprocessing
 from contextlib import contextmanager
 
 
@@ -100,5 +101,4 @@ def get_n_gpu():
 	return len(physical_devices)
 
 def get_n_cpu():
-	physical_devices = get_physical_devices('CPU')
-	return len(physical_devices)
\ No newline at end of file
+	return multiprocessing.cpu_count()
\ No newline at end of file
